#!/bin/bash
# test we are root
if [ "$(id -u)" != "0" ]; then
   echo "run as root now exitting"
   exit 1
fi

export CFLAGS='-flto=auto -Os -pipe -march=armv8-a+crc -mtune=cortex-a72   '
export CXXFLAGS='-flto=auto -Os -pipe -fno-exceptions -fno-rtti -march=armv8-a+crc -mtune=cortex-a72  '
export PKG_CONFIG_PATH=/usr/local/lib/pkgconfig:/usr/lib/pkgconfig
echo $CFLAGS && echo $CXXFLAGS

P=scdoc
V=1.11.2
SRC=$P-$V
USER=`cat /etc/sysconfig/tcuser`
LIST="compiletc submitqc "
for Z in $LIST 
    do 
    su -c "tce-load -i $Z" $USER
done

# list may be larger than loaded
cd /usr/local/lib
rm -rf *.la
rm -rf gcc/aarch64-unknown-linux-gnu/12.2.0/plugin/*.la
rm -rf gcc/aarch64-unknown-linux-gnu/12.2.0/*.la
rm -rf gcc/armv7l-unknown-linux-gnueabihf/12.2.0/plugin/libcc1plugin.la
rm -rf gcc/armv7l-unknown-linux-gnueabihf/12.2.0/plugin/libcp1plugin.la
rm -rf gcc/armv7l-unknown-linux-gnueabihf/12.2.0/liblto_plugin.la
rm -rf gprofng/*.la 
rm -rf python3.8/site-packages/*.la
rm -rf pkcs11/*.la
rm -rf cairo/*.la
rm -rf gtk-2.0/modules/*.la
rm -rf gtk-2.0/2.10.0/printbackends/*.la
rm -rf gtk-2.0/2.10.0/immodules/*.la
rm -rf gtk-2.0/2.10.0/engines/*.la
rm -rf imlib2/loaders/*.la
rm -rf imlib2/filters/*.la
rm -rf gdk-pixbuf-2.0/2.10.0/loaders/*.la
rm -rf pulseaudio/libpulsedsp.la
rm -rf pulseaudio/libpulsecore-13.0.la
rm -rf pulseaudio/libpulsecommon-13.0.la
rm -rf libv4l/v4l2convert.la
rm -rf libv4l/v4l1compat.la
rm -rf libv4l/plugins/libv4l-mplane.la
rm -rf vala-0.46/libvalaccodegen.la
cd /tmp
rm -rf /usr/lib/*.la
find / -name *.la

cd /tmp
su -c "/usr/local/bin/wget -nc --no-check-certificate \
https://git.sr.ht/~sircmpwn/$P/archive/$V.tar.gz " $USER
tar xvf $V*gz
cd $SRC
make PREFIX=/usr/local # 5 secs
make PREFIX=/usr/local install
cd /tmp

# dev
#####
mkdir -p $P-dev/usr/local/lib/pkgconfig
mv /usr/local/share/pkgconfig/$P.pc $P-dev/usr/local/lib/pkgconfig/

# main
######
mkdir -p $P/usr/share/doc/$P
cp $SRC/COPYING  $P/usr/share/doc/$P/
mkdir -p $P/usr/local/bin
mv /usr/local/bin/$P $P/usr/local/bin
strip --strip-unneeded $P/usr/local/bin/$P

# TCE
#######
LIST="$P $P-dev "
for Z in $LIST
do
	mksquashfs $Z $Z.tcz
	md5sum $Z.tcz > $Z.tcz.md5.txt
	cd $Z
	find usr -not -type d > /tmp/$Z.tcz.list
        sed 's|usr|/usr|g' -i /tmp/$Z.tcz.list
	cd /tmp
done

ls -hal

echo 'Title:          scdoc.dev.tcz 
Description:    dev file  
Version:        1.11.2
Author:         Drew DeVault
Original-site:  https://git.sr.ht/%7Esircmpwn/scdoc/
Copying-policy: Accompanied 
Size:           4.0K		
Extension_by:   aus9 
Tags:           man-db man 
Comments:       one pc file

Change-log:     2023/09/22 v 1.11.2 on 14.x
Current:        2023/09/22            ' > $P-dev.tcz.info
echo 'scdoc.tcz ' > $P-dev.tcz.dep


echo 'Title:          scdoc.tcz 
Description:    small man page generator 
Version:        1.11.2
Author:         Drew DeVault
Original-site:  https://git.sr.ht/%7Esircmpwn/scdoc/
Copying-policy: Accompanied 
Size:           296K	
Extension_by:   aus9 
Tags:           man-db man 
Comments:       Simple man page generator 
                written in C99
                
                Input files must use the UTF-8 encoding

Change-log:     2023/09/22 v 1.11.2 on 14.x
Current:        2023/09/22                   ' > $P.tcz.info

